"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetSemestersRequest(object):
    """Implementation of the 'GetSemestersRequest' model.

    Get Semesters Request Model

    Attributes:
        semester_i_ds (List[int]): The requested semester IDs.
        start_date (datetime): The start date for the range. All semesters that are
            on or after this day.  Default: **today’s date**
        end_date (datetime): The end date for the range. All semesters that are on or
            before this day.  Default: **StartDate**
        active (bool): When true, the response only contains semesters which are
            activated. When false, only deactivated semesters are returned.  Default:
            **All semesters**
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "semester_i_ds": "SemesterIDs",
        "start_date": "StartDate",
        "end_date": "EndDate",
        "active": "Active",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "semester_i_ds",
        "start_date",
        "end_date",
        "active",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        semester_i_ds=APIHelper.SKIP,
        start_date=APIHelper.SKIP,
        end_date=APIHelper.SKIP,
        active=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetSemestersRequest instance."""
        # Initialize members of the class
        if semester_i_ds is not APIHelper.SKIP:
            self.semester_i_ds = semester_i_ds
        if start_date is not APIHelper.SKIP:
            self.start_date =\
                 APIHelper.apply_datetime_converter(
                start_date, APIHelper.RFC3339DateTime)\
                 if start_date else None
        if end_date is not APIHelper.SKIP:
            self.end_date =\
                 APIHelper.apply_datetime_converter(
                end_date, APIHelper.RFC3339DateTime)\
                 if end_date else None
        if active is not APIHelper.SKIP:
            self.active = active
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        semester_i_ds =\
            dictionary.get("SemesterIDs")\
            if dictionary.get("SemesterIDs")\
                else APIHelper.SKIP
        start_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("StartDate")).datetime\
            if dictionary.get("StartDate") else APIHelper.SKIP
        end_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EndDate")).datetime\
            if dictionary.get("EndDate") else APIHelper.SKIP
        active =\
            dictionary.get("Active")\
            if "Active" in dictionary.keys()\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(semester_i_ds,
                   start_date,
                   end_date,
                   active,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _semester_i_ds=(
            self.semester_i_ds
            if hasattr(self, "semester_i_ds")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"semester_i_ds={_semester_i_ds!r}, "
            f"start_date={_start_date!r}, "
            f"end_date={_end_date!r}, "
            f"active={_active!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _semester_i_ds=(
            self.semester_i_ds
            if hasattr(self, "semester_i_ds")
            else None
        )
        _start_date=(
            self.start_date
            if hasattr(self, "start_date")
            else None
        )
        _end_date=(
            self.end_date
            if hasattr(self, "end_date")
            else None
        )
        _active=(
            self.active
            if hasattr(self, "active")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"semester_i_ds={_semester_i_ds!s}, "
            f"start_date={_start_date!s}, "
            f"end_date={_end_date!s}, "
            f"active={_active!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class PurchasedItem(object):
    """Implementation of the 'PurchasedItem' model.

    Attributes:
        sale_detail_id (int): The ID which gets assigned to the item when item is
            added to the cart.
        id (int): The ID of the purchased item. Use this ID when calling the GET
            Services or GET Products endpoint.
        is_service (bool): When `true`, indicates that the purchased item was a
            pricing option for a service.
        barcode_id (str): The barcode number of the purchased item. Use this ID when
            calling the GET Products endpoint.
        description (str): The description of the sale transaction/pricing option.
        contract_id (int): The contract purchased by the client. Use this ID when
            calling the GET Contract endpoint.
        category_id (int): The revenue category ID used for sale. Use this ID when
            calling the GET Categories endpoint.
        sub_category_id (int): The ID of revenue subcategory.
        unit_price (float): er Unit Price of the item purchased.
        quantity (int): Quantity of the purchased item, applicable for products only.
            Note: Negative numbers indicate returned items.
        discount_percent (float): The percent discount that was applied to the items
            subtotal.
        discount_amount (float): The total discount amount that was applied to the
            items subtotal.
        tax_1 (float): A decimal representation of the first tax rate that was
            applied to the items subtotal.
        tax_2 (float): A decimal representation of the second tax rate that was
            applied to the items subtotal.
        tax_3 (float): A decimal representation of the third tax rate that was
            applied to the items subtotal.
        tax_4 (float): A decimal representation of the fourth tax rate that was
            applied to the items subtotal.
        tax_5 (float): A decimal representation of the fifth tax rate that was
            applied to the items subtotal.
        tax_amount (float): Total tax amount that is summation of tax1, tax2, tax3,
            tax4 and tax5.
        total_amount (float): The items total, once discounts and/or tax was applied.
        notes (str): Note made by the customer while purchasing item.
        returned (bool): When `true`, indicates that the purchased item is returned,
            `false` otherwise.
        payment_ref_id (int): The payment reference ID generated during payment of
            sold item.
        exp_date (datetime): The expiration date of the pricing option purchased.
        active_date (datetime): The activation date of pricing option purchased.
        gift_card_barcode_id (str): Gift Card BarcodeId

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "sale_detail_id": "SaleDetailId",
        "id": "Id",
        "is_service": "IsService",
        "barcode_id": "BarcodeId",
        "description": "Description",
        "contract_id": "ContractId",
        "category_id": "CategoryId",
        "sub_category_id": "SubCategoryId",
        "unit_price": "UnitPrice",
        "quantity": "Quantity",
        "discount_percent": "DiscountPercent",
        "discount_amount": "DiscountAmount",
        "tax_1": "Tax1",
        "tax_2": "Tax2",
        "tax_3": "Tax3",
        "tax_4": "Tax4",
        "tax_5": "Tax5",
        "tax_amount": "TaxAmount",
        "total_amount": "TotalAmount",
        "notes": "Notes",
        "returned": "Returned",
        "payment_ref_id": "PaymentRefId",
        "exp_date": "ExpDate",
        "active_date": "ActiveDate",
        "gift_card_barcode_id": "GiftCardBarcodeId",
    }

    _optionals = [
        "sale_detail_id",
        "id",
        "is_service",
        "barcode_id",
        "description",
        "contract_id",
        "category_id",
        "sub_category_id",
        "unit_price",
        "quantity",
        "discount_percent",
        "discount_amount",
        "tax_1",
        "tax_2",
        "tax_3",
        "tax_4",
        "tax_5",
        "tax_amount",
        "total_amount",
        "notes",
        "returned",
        "payment_ref_id",
        "exp_date",
        "active_date",
        "gift_card_barcode_id",
    ]

    def __init__(
        self,
        sale_detail_id=APIHelper.SKIP,
        id=APIHelper.SKIP,
        is_service=APIHelper.SKIP,
        barcode_id=APIHelper.SKIP,
        description=APIHelper.SKIP,
        contract_id=APIHelper.SKIP,
        category_id=APIHelper.SKIP,
        sub_category_id=APIHelper.SKIP,
        unit_price=APIHelper.SKIP,
        quantity=APIHelper.SKIP,
        discount_percent=APIHelper.SKIP,
        discount_amount=APIHelper.SKIP,
        tax_1=APIHelper.SKIP,
        tax_2=APIHelper.SKIP,
        tax_3=APIHelper.SKIP,
        tax_4=APIHelper.SKIP,
        tax_5=APIHelper.SKIP,
        tax_amount=APIHelper.SKIP,
        total_amount=APIHelper.SKIP,
        notes=APIHelper.SKIP,
        returned=APIHelper.SKIP,
        payment_ref_id=APIHelper.SKIP,
        exp_date=APIHelper.SKIP,
        active_date=APIHelper.SKIP,
        gift_card_barcode_id=APIHelper.SKIP):
        """Initialize a PurchasedItem instance."""
        # Initialize members of the class
        if sale_detail_id is not APIHelper.SKIP:
            self.sale_detail_id = sale_detail_id
        if id is not APIHelper.SKIP:
            self.id = id
        if is_service is not APIHelper.SKIP:
            self.is_service = is_service
        if barcode_id is not APIHelper.SKIP:
            self.barcode_id = barcode_id
        if description is not APIHelper.SKIP:
            self.description = description
        if contract_id is not APIHelper.SKIP:
            self.contract_id = contract_id
        if category_id is not APIHelper.SKIP:
            self.category_id = category_id
        if sub_category_id is not APIHelper.SKIP:
            self.sub_category_id = sub_category_id
        if unit_price is not APIHelper.SKIP:
            self.unit_price = unit_price
        if quantity is not APIHelper.SKIP:
            self.quantity = quantity
        if discount_percent is not APIHelper.SKIP:
            self.discount_percent = discount_percent
        if discount_amount is not APIHelper.SKIP:
            self.discount_amount = discount_amount
        if tax_1 is not APIHelper.SKIP:
            self.tax_1 = tax_1
        if tax_2 is not APIHelper.SKIP:
            self.tax_2 = tax_2
        if tax_3 is not APIHelper.SKIP:
            self.tax_3 = tax_3
        if tax_4 is not APIHelper.SKIP:
            self.tax_4 = tax_4
        if tax_5 is not APIHelper.SKIP:
            self.tax_5 = tax_5
        if tax_amount is not APIHelper.SKIP:
            self.tax_amount = tax_amount
        if total_amount is not APIHelper.SKIP:
            self.total_amount = total_amount
        if notes is not APIHelper.SKIP:
            self.notes = notes
        if returned is not APIHelper.SKIP:
            self.returned = returned
        if payment_ref_id is not APIHelper.SKIP:
            self.payment_ref_id = payment_ref_id
        if exp_date is not APIHelper.SKIP:
            self.exp_date =\
                 APIHelper.apply_datetime_converter(
                exp_date, APIHelper.RFC3339DateTime)\
                 if exp_date else None
        if active_date is not APIHelper.SKIP:
            self.active_date =\
                 APIHelper.apply_datetime_converter(
                active_date, APIHelper.RFC3339DateTime)\
                 if active_date else None
        if gift_card_barcode_id is not APIHelper.SKIP:
            self.gift_card_barcode_id = gift_card_barcode_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        sale_detail_id =\
            dictionary.get("SaleDetailId")\
            if dictionary.get("SaleDetailId")\
                else APIHelper.SKIP
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        is_service =\
            dictionary.get("IsService")\
            if "IsService" in dictionary.keys()\
                else APIHelper.SKIP
        barcode_id =\
            dictionary.get("BarcodeId")\
            if dictionary.get("BarcodeId")\
                else APIHelper.SKIP
        description =\
            dictionary.get("Description")\
            if dictionary.get("Description")\
                else APIHelper.SKIP
        contract_id =\
            dictionary.get("ContractId")\
            if dictionary.get("ContractId")\
                else APIHelper.SKIP
        category_id =\
            dictionary.get("CategoryId")\
            if dictionary.get("CategoryId")\
                else APIHelper.SKIP
        sub_category_id =\
            dictionary.get("SubCategoryId")\
            if dictionary.get("SubCategoryId")\
                else APIHelper.SKIP
        unit_price =\
            dictionary.get("UnitPrice")\
            if dictionary.get("UnitPrice")\
                else APIHelper.SKIP
        quantity =\
            dictionary.get("Quantity")\
            if dictionary.get("Quantity")\
                else APIHelper.SKIP
        discount_percent =\
            dictionary.get("DiscountPercent")\
            if dictionary.get("DiscountPercent")\
                else APIHelper.SKIP
        discount_amount =\
            dictionary.get("DiscountAmount")\
            if dictionary.get("DiscountAmount")\
                else APIHelper.SKIP
        tax_1 =\
            dictionary.get("Tax1")\
            if dictionary.get("Tax1")\
                else APIHelper.SKIP
        tax_2 =\
            dictionary.get("Tax2")\
            if dictionary.get("Tax2")\
                else APIHelper.SKIP
        tax_3 =\
            dictionary.get("Tax3")\
            if dictionary.get("Tax3")\
                else APIHelper.SKIP
        tax_4 =\
            dictionary.get("Tax4")\
            if dictionary.get("Tax4")\
                else APIHelper.SKIP
        tax_5 =\
            dictionary.get("Tax5")\
            if dictionary.get("Tax5")\
                else APIHelper.SKIP
        tax_amount =\
            dictionary.get("TaxAmount")\
            if dictionary.get("TaxAmount")\
                else APIHelper.SKIP
        total_amount =\
            dictionary.get("TotalAmount")\
            if dictionary.get("TotalAmount")\
                else APIHelper.SKIP
        notes =\
            dictionary.get("Notes")\
            if dictionary.get("Notes")\
                else APIHelper.SKIP
        returned =\
            dictionary.get("Returned")\
            if "Returned" in dictionary.keys()\
                else APIHelper.SKIP
        payment_ref_id =\
            dictionary.get("PaymentRefId")\
            if dictionary.get("PaymentRefId")\
                else APIHelper.SKIP
        exp_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ExpDate")).datetime\
            if dictionary.get("ExpDate") else APIHelper.SKIP
        active_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ActiveDate")).datetime\
            if dictionary.get("ActiveDate") else APIHelper.SKIP
        gift_card_barcode_id =\
            dictionary.get("GiftCardBarcodeId")\
            if dictionary.get("GiftCardBarcodeId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(sale_detail_id,
                   id,
                   is_service,
                   barcode_id,
                   description,
                   contract_id,
                   category_id,
                   sub_category_id,
                   unit_price,
                   quantity,
                   discount_percent,
                   discount_amount,
                   tax_1,
                   tax_2,
                   tax_3,
                   tax_4,
                   tax_5,
                   tax_amount,
                   total_amount,
                   notes,
                   returned,
                   payment_ref_id,
                   exp_date,
                   active_date,
                   gift_card_barcode_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _sale_detail_id=(
            self.sale_detail_id
            if hasattr(self, "sale_detail_id")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _is_service=(
            self.is_service
            if hasattr(self, "is_service")
            else None
        )
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _contract_id=(
            self.contract_id
            if hasattr(self, "contract_id")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _sub_category_id=(
            self.sub_category_id
            if hasattr(self, "sub_category_id")
            else None
        )
        _unit_price=(
            self.unit_price
            if hasattr(self, "unit_price")
            else None
        )
        _quantity=(
            self.quantity
            if hasattr(self, "quantity")
            else None
        )
        _discount_percent=(
            self.discount_percent
            if hasattr(self, "discount_percent")
            else None
        )
        _discount_amount=(
            self.discount_amount
            if hasattr(self, "discount_amount")
            else None
        )
        _tax_1=(
            self.tax_1
            if hasattr(self, "tax_1")
            else None
        )
        _tax_2=(
            self.tax_2
            if hasattr(self, "tax_2")
            else None
        )
        _tax_3=(
            self.tax_3
            if hasattr(self, "tax_3")
            else None
        )
        _tax_4=(
            self.tax_4
            if hasattr(self, "tax_4")
            else None
        )
        _tax_5=(
            self.tax_5
            if hasattr(self, "tax_5")
            else None
        )
        _tax_amount=(
            self.tax_amount
            if hasattr(self, "tax_amount")
            else None
        )
        _total_amount=(
            self.total_amount
            if hasattr(self, "total_amount")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _returned=(
            self.returned
            if hasattr(self, "returned")
            else None
        )
        _payment_ref_id=(
            self.payment_ref_id
            if hasattr(self, "payment_ref_id")
            else None
        )
        _exp_date=(
            self.exp_date
            if hasattr(self, "exp_date")
            else None
        )
        _active_date=(
            self.active_date
            if hasattr(self, "active_date")
            else None
        )
        _gift_card_barcode_id=(
            self.gift_card_barcode_id
            if hasattr(self, "gift_card_barcode_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale_detail_id={_sale_detail_id!r}, "
            f"id={_id!r}, "
            f"is_service={_is_service!r}, "
            f"barcode_id={_barcode_id!r}, "
            f"description={_description!r}, "
            f"contract_id={_contract_id!r}, "
            f"category_id={_category_id!r}, "
            f"sub_category_id={_sub_category_id!r}, "
            f"unit_price={_unit_price!r}, "
            f"quantity={_quantity!r}, "
            f"discount_percent={_discount_percent!r}, "
            f"discount_amount={_discount_amount!r}, "
            f"tax_1={_tax_1!r}, "
            f"tax_2={_tax_2!r}, "
            f"tax_3={_tax_3!r}, "
            f"tax_4={_tax_4!r}, "
            f"tax_5={_tax_5!r}, "
            f"tax_amount={_tax_amount!r}, "
            f"total_amount={_total_amount!r}, "
            f"notes={_notes!r}, "
            f"returned={_returned!r}, "
            f"payment_ref_id={_payment_ref_id!r}, "
            f"exp_date={_exp_date!r}, "
            f"active_date={_active_date!r}, "
            f"gift_card_barcode_id={_gift_card_barcode_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _sale_detail_id=(
            self.sale_detail_id
            if hasattr(self, "sale_detail_id")
            else None
        )
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _is_service=(
            self.is_service
            if hasattr(self, "is_service")
            else None
        )
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _description=(
            self.description
            if hasattr(self, "description")
            else None
        )
        _contract_id=(
            self.contract_id
            if hasattr(self, "contract_id")
            else None
        )
        _category_id=(
            self.category_id
            if hasattr(self, "category_id")
            else None
        )
        _sub_category_id=(
            self.sub_category_id
            if hasattr(self, "sub_category_id")
            else None
        )
        _unit_price=(
            self.unit_price
            if hasattr(self, "unit_price")
            else None
        )
        _quantity=(
            self.quantity
            if hasattr(self, "quantity")
            else None
        )
        _discount_percent=(
            self.discount_percent
            if hasattr(self, "discount_percent")
            else None
        )
        _discount_amount=(
            self.discount_amount
            if hasattr(self, "discount_amount")
            else None
        )
        _tax_1=(
            self.tax_1
            if hasattr(self, "tax_1")
            else None
        )
        _tax_2=(
            self.tax_2
            if hasattr(self, "tax_2")
            else None
        )
        _tax_3=(
            self.tax_3
            if hasattr(self, "tax_3")
            else None
        )
        _tax_4=(
            self.tax_4
            if hasattr(self, "tax_4")
            else None
        )
        _tax_5=(
            self.tax_5
            if hasattr(self, "tax_5")
            else None
        )
        _tax_amount=(
            self.tax_amount
            if hasattr(self, "tax_amount")
            else None
        )
        _total_amount=(
            self.total_amount
            if hasattr(self, "total_amount")
            else None
        )
        _notes=(
            self.notes
            if hasattr(self, "notes")
            else None
        )
        _returned=(
            self.returned
            if hasattr(self, "returned")
            else None
        )
        _payment_ref_id=(
            self.payment_ref_id
            if hasattr(self, "payment_ref_id")
            else None
        )
        _exp_date=(
            self.exp_date
            if hasattr(self, "exp_date")
            else None
        )
        _active_date=(
            self.active_date
            if hasattr(self, "active_date")
            else None
        )
        _gift_card_barcode_id=(
            self.gift_card_barcode_id
            if hasattr(self, "gift_card_barcode_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"sale_detail_id={_sale_detail_id!s}, "
            f"id={_id!s}, "
            f"is_service={_is_service!s}, "
            f"barcode_id={_barcode_id!s}, "
            f"description={_description!s}, "
            f"contract_id={_contract_id!s}, "
            f"category_id={_category_id!s}, "
            f"sub_category_id={_sub_category_id!s}, "
            f"unit_price={_unit_price!s}, "
            f"quantity={_quantity!s}, "
            f"discount_percent={_discount_percent!s}, "
            f"discount_amount={_discount_amount!s}, "
            f"tax_1={_tax_1!s}, "
            f"tax_2={_tax_2!s}, "
            f"tax_3={_tax_3!s}, "
            f"tax_4={_tax_4!s}, "
            f"tax_5={_tax_5!s}, "
            f"tax_amount={_tax_amount!s}, "
            f"total_amount={_total_amount!s}, "
            f"notes={_notes!s}, "
            f"returned={_returned!s}, "
            f"payment_ref_id={_payment_ref_id!s}, "
            f"exp_date={_exp_date!s}, "
            f"active_date={_active_date!s}, "
            f"gift_card_barcode_id={_gift_card_barcode_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class UpcomingAutopayEvent(object):
    """Implementation of the 'UpcomingAutopayEvent' model.

    Attributes:
        client_contract_id (int): The ID of the contract.
        charge_amount (float): The amount charged.
        subtotal (float): Subtotal before tax.
        tax (float): Tax amount.
        payment_method (PaymentMethodEnum): The payment method.
        schedule_date (datetime): The date and time of the next payment.
        product_id (int): The product id.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "client_contract_id": "ClientContractId",
        "charge_amount": "ChargeAmount",
        "subtotal": "Subtotal",
        "tax": "Tax",
        "payment_method": "PaymentMethod",
        "schedule_date": "ScheduleDate",
        "product_id": "ProductId",
    }

    _optionals = [
        "client_contract_id",
        "charge_amount",
        "subtotal",
        "tax",
        "payment_method",
        "schedule_date",
        "product_id",
    ]

    def __init__(
        self,
        client_contract_id=APIHelper.SKIP,
        charge_amount=APIHelper.SKIP,
        subtotal=APIHelper.SKIP,
        tax=APIHelper.SKIP,
        payment_method=APIHelper.SKIP,
        schedule_date=APIHelper.SKIP,
        product_id=APIHelper.SKIP):
        """Initialize a UpcomingAutopayEvent instance."""
        # Initialize members of the class
        if client_contract_id is not APIHelper.SKIP:
            self.client_contract_id = client_contract_id
        if charge_amount is not APIHelper.SKIP:
            self.charge_amount = charge_amount
        if subtotal is not APIHelper.SKIP:
            self.subtotal = subtotal
        if tax is not APIHelper.SKIP:
            self.tax = tax
        if payment_method is not APIHelper.SKIP:
            self.payment_method = payment_method
        if schedule_date is not APIHelper.SKIP:
            self.schedule_date =\
                 APIHelper.apply_datetime_converter(
                schedule_date, APIHelper.RFC3339DateTime)\
                 if schedule_date else None
        if product_id is not APIHelper.SKIP:
            self.product_id = product_id

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        client_contract_id =\
            dictionary.get("ClientContractId")\
            if dictionary.get("ClientContractId")\
                else APIHelper.SKIP
        charge_amount =\
            dictionary.get("ChargeAmount")\
            if dictionary.get("ChargeAmount")\
                else APIHelper.SKIP
        subtotal =\
            dictionary.get("Subtotal")\
            if dictionary.get("Subtotal")\
                else APIHelper.SKIP
        tax =\
            dictionary.get("Tax")\
            if dictionary.get("Tax")\
                else APIHelper.SKIP
        payment_method =\
            dictionary.get("PaymentMethod")\
            if dictionary.get("PaymentMethod")\
                else APIHelper.SKIP
        schedule_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("ScheduleDate")).datetime\
            if dictionary.get("ScheduleDate") else APIHelper.SKIP
        product_id =\
            dictionary.get("ProductId")\
            if dictionary.get("ProductId")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(client_contract_id,
                   charge_amount,
                   subtotal,
                   tax,
                   payment_method,
                   schedule_date,
                   product_id)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _client_contract_id=(
            self.client_contract_id
            if hasattr(self, "client_contract_id")
            else None
        )
        _charge_amount=(
            self.charge_amount
            if hasattr(self, "charge_amount")
            else None
        )
        _subtotal=(
            self.subtotal
            if hasattr(self, "subtotal")
            else None
        )
        _tax=(
            self.tax
            if hasattr(self, "tax")
            else None
        )
        _payment_method=(
            self.payment_method
            if hasattr(self, "payment_method")
            else None
        )
        _schedule_date=(
            self.schedule_date
            if hasattr(self, "schedule_date")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_contract_id={_client_contract_id!r}, "
            f"charge_amount={_charge_amount!r}, "
            f"subtotal={_subtotal!r}, "
            f"tax={_tax!r}, "
            f"payment_method={_payment_method!r}, "
            f"schedule_date={_schedule_date!r}, "
            f"product_id={_product_id!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _client_contract_id=(
            self.client_contract_id
            if hasattr(self, "client_contract_id")
            else None
        )
        _charge_amount=(
            self.charge_amount
            if hasattr(self, "charge_amount")
            else None
        )
        _subtotal=(
            self.subtotal
            if hasattr(self, "subtotal")
            else None
        )
        _tax=(
            self.tax
            if hasattr(self, "tax")
            else None
        )
        _payment_method=(
            self.payment_method
            if hasattr(self, "payment_method")
            else None
        )
        _schedule_date=(
            self.schedule_date
            if hasattr(self, "schedule_date")
            else None
        )
        _product_id=(
            self.product_id
            if hasattr(self, "product_id")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"client_contract_id={_client_contract_id!s}, "
            f"charge_amount={_charge_amount!s}, "
            f"subtotal={_subtotal!s}, "
            f"tax={_tax!s}, "
            f"payment_method={_payment_method!s}, "
            f"schedule_date={_schedule_date!s}, "
            f"product_id={_product_id!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: D410, E501, E101, D206
from apimatic_core.authentication.multiple.single_auth import (
    Single,
)
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter

from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.configuration import (
    Server,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.http.http_method_enum import (
    HttpMethodEnum,
)
from mindbodypublicapi.models.add_appointment_add_on_response import (
    AddAppointmentAddOnResponse,
)
from mindbodypublicapi.models.add_appointment_response import (
    AddAppointmentResponse,
)
from mindbodypublicapi.models.add_availabilities_response import (
    AddAvailabilitiesResponse,
)
from mindbodypublicapi.models.add_multiple_appointments_response import (
    AddMultipleAppointmentsResponse,
)
from mindbodypublicapi.models.get_active_session_times_response import (
    GetActiveSessionTimesResponse,
)
from mindbodypublicapi.models.get_add_ons_response import (
    GetAddOnsResponse,
)
from mindbodypublicapi.models.get_appointment_options_response import (
    GetAppointmentOptionsResponse,
)
from mindbodypublicapi.models.get_available_dates_response import (
    GetAvailableDatesResponse,
)
from mindbodypublicapi.models.get_bookable_items_response import (
    GetBookableItemsResponse,
)
from mindbodypublicapi.models.get_schedule_items_response import (
    GetScheduleItemsResponse,
)
from mindbodypublicapi.models.get_staff_appointments_response import (
    GetStaffAppointmentsResponse,
)
from mindbodypublicapi.models.get_unavailabilities_response import (
    GetUnavailabilitiesResponse,
)
from mindbodypublicapi.models.update_appointment_response import (
    UpdateAppointmentResponse,
)
from mindbodypublicapi.models.update_availability_response import (
    UpdateAvailabilityResponse,
)


class AppointmentController(BaseController):
    """A Controller to access Endpoints in the mindbodypublicapi API."""

    def __init__(self, config):
        """Initialize AppointmentController object."""
        super(AppointmentController, self).__init__(config)

    def get_active_session_times(self,
                                 version,
                                 site_id,
                                 authorization=None,
                                 request_end_time=None,
                                 request_limit=None,
                                 request_offset=None,
                                 request_schedule_type=None,
                                 request_session_type_ids=None,
                                 request_start_time=None):
        """Perform a GET request to
        /public/v{version}/appointment/activesessiontimes.

        This is not appointment availability but rather the active business hours for
        studios and which increments services can be booked at. See BookableItems for
        appointment availability.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_end_time (datetime, optional): Filters results to times that end
                on or before this time on the current date. Any date provided is
                ignored..  <br />Default: **23:59:59**
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_schedule_type (RequestScheduleTypeEnum, optional): Filters on the
                provided the schedule type. Either `SessionTypeIds` or `ScheduleType`
                must be provided.
            request_session_type_ids (List[int], optional): Filters on the provided
                session type IDs. Either `SessionTypeIds` or `ScheduleType` must be
                provided.
            request_start_time (datetime, optional): Filters results to times that
                start on or after this time on the current date. Any date provided is
                ignored.  <br />Default: **00:00:00**

        Returns:
            GetActiveSessionTimesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/activesessiontimes")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.endTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_time)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.scheduleType")
                .value(request_schedule_type))
            .query_param(Parameter()
                .key("request.sessionTypeIds")
                .value(request_session_type_ids))
            .query_param(Parameter()
                .key("request.startTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_time)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetActiveSessionTimesResponse.from_dictionary),
        ).execute()

    def get_add_ons(self,
                    version,
                    site_id,
                    authorization=None,
                    request_limit=None,
                    request_offset=None,
                    request_staff_id=None):
        """Perform a GET request to /public/v{version}/appointment/addons.

        Get active appointment add-ons.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_staff_id (int, optional): Filter to add-ons only performed by
                this staff member.

        Returns:
            GetAddOnsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/addons")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.staffId")
                .value(request_staff_id))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetAddOnsResponse.from_dictionary),
        ).execute()

    def get_appointment_options(self,
                                version,
                                site_id,
                                authorization=None):
        """Perform a GET request to
        /public/v{version}/appointment/appointmentoptions.

        This endpoint has no query parameters.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            GetAppointmentOptionsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/appointmentoptions")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetAppointmentOptionsResponse.from_dictionary),
        ).execute()

    def get_available_dates(self,
                            version,
                            request_session_type_id,
                            site_id,
                            authorization=None,
                            request_end_date=None,
                            request_location_id=None,
                            request_staff_id=None,
                            request_start_date=None):
        """Perform a GET request to
        /public/v{version}/appointment/availabledates.

        Returns a list of dates to narrow down staff availability when booking. Dates
        are those which staff are scheduled to work and do not guarantee booking
        availabilities. After this call is made, use GET BookableItems to retrieve
        availabilities for specific dates before booking.

        Args:
            version (str): version of the api.
            request_session_type_id (int): required requested session type ID.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_end_date (datetime, optional): The end date of the requested date
                range.   <br />Default: **StartDate**
            request_location_id (int, optional): optional requested location ID.
            request_staff_id (int, optional): optional requested staff ID.
            request_start_date (datetime, optional): The start date of the requested
                date range. If omitted, the default is used.  <br />Default:
                **today’s date**

        Returns:
            GetAvailableDatesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/availabledates")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .query_param(Parameter()
                .key("request.sessionTypeId")
                .value(request_session_type_id))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.endDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date)))
            .query_param(Parameter()
                .key("request.locationId")
                .value(request_location_id))
            .query_param(Parameter()
                .key("request.staffId")
                .value(request_staff_id))
            .query_param(Parameter()
                .key("request.startDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetAvailableDatesResponse.from_dictionary),
        ).execute()

    def get_bookable_items(self,
                           version,
                           request_session_type_ids,
                           site_id,
                           authorization=None,
                           request_appointment_id=None,
                           request_end_date=None,
                           request_ignore_default_session_length=None,
                           request_include_resource_availability=None,
                           request_limit=None,
                           request_location_ids=None,
                           request_offset=None,
                           request_staff_ids=None,
                           request_start_date=None):
        """Perform a GET request to
        /public/v{version}/appointment/bookableitems.

        Returns a list of availabilities with the information needed to book
        appointments. Availabilities include information such as the location and its
        amenities, staff members, programs, and session types. Recommended to use
        with GET AvailableDates to see what dates the staff is scheduled to work and
        narrow down the dates searched. Recommended to use with GET
        ActiveSessionTimes to see which increments each business allows for booking
        appointments.
        Notes:
        - With a wider range of dates, this call may take longer to return results.
        - With a higher number of request.sessionTypeIds, this call may take longer
        to return results.

        Args:
            version (str): version of the api.
            request_session_type_ids (List[int]): A list of the requested session
                type IDs.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_appointment_id (int, optional): If provided, filters out the
                appointment with this ID.
            request_end_date (datetime, optional): The end date of the requested date
                range.   <br />Default: **StartDate**
            request_ignore_default_session_length (bool, optional): When `true`,
                availabilities that are non-default return, for example, a 30-minute
                availability with a 60-minute default session length.<br />  When
                `false`, only availabilities that have the default session length
                return.
            request_include_resource_availability (bool, optional): When `true`,
                resource availabilities for the session type are returned.<br />
                When `false`, resource availabilities are not returned default.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_ids (List[int], optional): A list of the requested
                location IDs.
            request_offset (int, optional): Page offset, defaults to 0.
            request_staff_ids (List[int], optional): A list of the requested staff
                IDs. Omit parameter to return all staff availabilities.
            request_start_date (datetime, optional): The start date of the requested
                date range.   <br />Default: **today’s date**

        Returns:
            GetBookableItemsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/bookableitems")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .query_param(Parameter()
                .key("request.sessionTypeIds")
                .value(request_session_type_ids))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.appointmentId")
                .value(request_appointment_id))
            .query_param(Parameter()
                .key("request.endDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date)))
            .query_param(Parameter()
                .key("request.ignoreDefaultSessionLength")
                .value(request_ignore_default_session_length))
            .query_param(Parameter()
                .key("request.includeResourceAvailability")
                .value(request_include_resource_availability))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationIds")
                .value(request_location_ids))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.staffIds")
                .value(request_staff_ids))
            .query_param(Parameter()
                .key("request.startDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetBookableItemsResponse.from_dictionary),
        ).execute()

    def get_schedule_items(self,
                           version,
                           site_id,
                           authorization=None,
                           request_end_date=None,
                           request_ignore_prep_finish_times=None,
                           request_limit=None,
                           request_location_ids=None,
                           request_offset=None,
                           request_staff_ids=None,
                           request_start_date=None):
        """Perform a GET request to
        /public/v{version}/appointment/scheduleitems.

        Returns a list of schedule items, including appointments, availabilities, and
        unavailabilities. Unavailabilities are the times at which appointments cannot
        be booked, for example, on holidays or after hours when the business is
        closed.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_end_date (datetime, optional): The end date of the requested date
                range.   <br />Default: **today’s date**
            request_ignore_prep_finish_times (bool, optional): When `true`,
                appointment preparation and finish unavailabilities are not returned.
                <br />Default: **false**
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_ids (List[int], optional): A list of requested location
                IDs.
            request_offset (int, optional): Page offset, defaults to 0.
            request_staff_ids (List[int], optional): A list of requested staff IDs.
            request_start_date (datetime, optional): The start date of the requested
                date range.   <br />Default: **today’s date**

        Returns:
            GetScheduleItemsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/scheduleitems")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.endDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date)))
            .query_param(Parameter()
                .key("request.ignorePrepFinishTimes")
                .value(request_ignore_prep_finish_times))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationIds")
                .value(request_location_ids))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.staffIds")
                .value(request_staff_ids))
            .query_param(Parameter()
                .key("request.startDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetScheduleItemsResponse.from_dictionary),
        ).execute()

    def get_staff_appointments(self,
                               version,
                               site_id,
                               authorization=None,
                               request_appointment_ids=None,
                               request_client_id=None,
                               request_end_date=None,
                               request_limit=None,
                               request_location_ids=None,
                               request_offset=None,
                               request_staff_ids=None,
                               request_start_date=None,
                               request_use_site_settings_staff_name=None):
        """Perform a GET request to
        /public/v{version}/appointment/staffappointments.

        Returns a list of appointments by staff member.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_appointment_ids (List[int], optional): A list of the requested
                appointment IDs.
            request_client_id (str, optional): The client ID to be returned.
            request_end_date (datetime, optional): The end date of the requested date
                range.   <br />Default: **StartDate**
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_ids (List[int], optional): A list of the requested
                location IDs.
            request_offset (int, optional): Page offset, defaults to 0.
            request_staff_ids (List[int], optional): List of staff IDs to be
                returned. Omit parameter to return staff appointments for all staff.
            request_start_date (datetime, optional): The start date of the requested
                date range. If omitted, the default is used.   <br />Default:
                **today's date**
            request_use_site_settings_staff_name (bool, optional): When `true`, the
                staff DisplayName will be populated based on site-level settings.
                When `false` or omitted, the staff DisplayName will contain only the
                FirstName.

        Returns:
            GetStaffAppointmentsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/staffappointments")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.appointmentIds")
                .value(request_appointment_ids))
            .query_param(Parameter()
                .key("request.clientId")
                .value(request_client_id))
            .query_param(Parameter()
                .key("request.endDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationIds")
                .value(request_location_ids))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.staffIds")
                .value(request_staff_ids))
            .query_param(Parameter()
                .key("request.startDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date)))
            .query_param(Parameter()
                .key("request.useSiteSettingsStaffName")
                .value(request_use_site_settings_staff_name))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetStaffAppointmentsResponse.from_dictionary),
        ).execute()

    def get_unavailabilities(self,
                             version,
                             site_id,
                             authorization=None,
                             request_end_date=None,
                             request_limit=None,
                             request_offset=None,
                             request_staff_ids=None,
                             request_start_date=None):
        """Perform a GET request to
        /public/v{version}/appointment/unavailabilities.

        Returns a list of unavailabilities. Unavailabilities are the times at which
        appointments cannot be booked, for example, on holidays or after hours when
        the business is closed.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_end_date (datetime, optional): The end date of the requested date
                range.   <br />Default: **today’s date**
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_staff_ids (List[int], optional): A list of requested staff IDs.
            request_start_date (datetime, optional): The start date of the requested
                date range.   <br />Default: **today’s date**

        Returns:
            GetUnavailabilitiesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/unavailabilities")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.endDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_end_date)))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.staffIds")
                .value(request_staff_ids))
            .query_param(Parameter()
                .key("request.startDate")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetUnavailabilitiesResponse.from_dictionary),
        ).execute()

    def add_appointment(self,
                        version,
                        request,
                        site_id,
                        authorization=None):
        """Perform a POST request to
        /public/v{version}/appointment/addappointment.

        A user token is required for this endpoint. To book an appointment, you must
        use a location ID, staff ID, client ID, session type ID, and the
        StartDateTime of the appointment. You can get most of this information using
        GET BookableItems.
        Note: Request deduplication is enabled for this endpoint. More information
        can be found in the [Request Deduplication
        Page](https://developers.mindbodyonline.com/ui/documentation/public-api#/net-s
        tandard-library/mindbody-public-api-v6-0/request-deduplication).
        Use the `X-RequestDeduplication-Skip` header to bypass deduplication if
        necessary. This may be useful in scenarios where you want to ensure a new
        appointment is created regardless of previous identical requests.

        Args:
            version (str): version of the api.
            request (AddAppointmentRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            AddAppointmentResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/addappointment")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AddAppointmentResponse.from_dictionary),
        ).execute()

    def add_appointment_add_on(self,
                               version,
                               request,
                               site_id,
                               authorization=None):
        """Perform a POST request to
        /public/v{version}/appointment/addappointmentaddon.

        This endpoint books an add-on on top of an existing, regular appointment. To
        book an add-on, you must use an existing appointment ID and session type ID.
        You can get a session type ID using `GET AppointmentAddOns`.

        Args:
            version (str): version of the api.
            request (AddAppointmentAddOnRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            AddAppointmentAddOnResponse: Response from the API. Created

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/addappointmentaddon")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AddAppointmentAddOnResponse.from_dictionary),
        ).execute()

    def add_multiple_appointments(self,
                                  version,
                                  request,
                                  site_id,
                                  authorization=None):
        """Perform a POST request to
        /public/v{version}/appointment/addmultipleappointments.

        A user token is required for this endpoint. To book appointments, you must
        provide a location ID, staff ID, client ID, session type ID, and the
        StartDateTime for each appointment.
        You can retrieve most of this information using the GET BookableItems
        endpoint.
        This endpoint will handle errors that occur during the appointment creation
        process and return a list of errors, as well as the request object that
        generated each outcome.
        You can pass the AddAppointmentRequestId for each request, or it will be
        automatically filled. This is intended to facilitate matching each request
        with the corresponding outcome.
        This endpoint will send one notification when multiple Appointments are
        booked by one Client on a given day.

        Args:
            version (str): version of the api.
            request (AddMultipleAppointmentsRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            AddMultipleAppointmentsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/addmultipleappointments")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AddMultipleAppointmentsResponse.from_dictionary),
        ).execute()

    def update_availability(self,
                            version,
                            site_id,
                            update_availability_request,
                            authorization=None):
        """Perform a PUT request to
        /public/v{version}/appointment/availabilities.

        To update the information for a specific availability or unavailability of
        the staff.<br />
        Note: You must have a staff user token with the required permissions.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            update_availability_request (UpdateAvailabilityRequest): The request body
                parameter.
            authorization (str, optional): A staff user authorization token.

        Returns:
            UpdateAvailabilityResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/availabilities")
            .http_method(HttpMethodEnum.PUT)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .body_param(Parameter()
                .value(update_availability_request))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(UpdateAvailabilityResponse.from_dictionary),
        ).execute()

    def add_availabilities(self,
                           version,
                           request,
                           site_id,
                           authorization=None):
        """Perform a POST request to
        /public/v{version}/appointment/availabilities.

        Add availabilities and unavailabilities for a staff member.<br />
        Note: You must have a staff user token with the required permissions.

        Args:
            version (str): version of the api.
            request (AddAvailabilitiesRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            AddAvailabilitiesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/availabilities")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AddAvailabilitiesResponse.from_dictionary),
        ).execute()

    def update_appointment(self,
                           version,
                           request,
                           site_id,
                           authorization=None):
        """Perform a POST request to
        /public/v{version}/appointment/updateappointment.

        To update the information for a specific appointment, you must have a staff
        user token with the proper permissions. Note that you can only update the
        appointment’s `StartDateTime`, `EndDateTime`, `StaffId`, `Notes`, and
        `SessionTypeId`.

        Args:
            version (str): version of the api.
            request (UpdateAppointmentRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            UpdateAppointmentResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/updateappointment")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(UpdateAppointmentResponse.from_dictionary),
        ).execute()

    def remove_from_waitlist(self,
                             version,
                             request_waitlist_entry_ids,
                             site_id,
                             authorization=None):
        """Perform a DELETE request to
        /public/v{version}/appointment/appointmentfromwaitlist.

        Remove an appointment from waitlist

        Args:
            version (str): version of the api.
            request_waitlist_entry_ids (List[int]): A list of `WaitlistEntryIds` to
                remove from the waiting list.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            void: Response from the API. This endpoint does not return a response. If
                a call to this endpoint results in a 204 No Content HTTP status code,
                then the call was successful.

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/appointmentfromwaitlist")
            .http_method(HttpMethodEnum.DELETE)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .query_param(Parameter()
                .key("request.waitlistEntryIds")
                .value(request_waitlist_entry_ids))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .auth(Single("API-Key")),
        ).execute()

    def delete_availability(self,
                            version,
                            site_id,
                            authorization=None,
                            delete_availability_request_availability_id=None,
                            delete_availability_request_test=None):
        """Perform a DELETE request to
        /public/v{version}/appointment/availability.

        This endpoint deletes the availability or unavailability.
        Note: You must have a staff user token with the required permissions.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            delete_availability_request_availability_id (int, optional): The ID of
                the availability or unavailability.
            delete_availability_request_test (bool, optional): When `true`, indicates
                that this is a test request and no data is deleted from the
                subscriber’s database.  When `false`, the record will be deleted.
                Default: **false**

        Returns:
            void: Response from the API. This endpoint does not return a response. If
                a call to this endpoint results in a 204 NoContent HTTP status code,
                then the call was successful.

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/availability")
            .http_method(HttpMethodEnum.DELETE)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("deleteAvailabilityRequest.availabilityId")
                .value(delete_availability_request_availability_id))
            .query_param(Parameter()
                .key("deleteAvailabilityRequest.test")
                .value(delete_availability_request_test))
            .auth(Single("API-Key")),
        ).execute()

    def delete_appointment_add_on(self,
                                  version,
                                  id,
                                  site_id,
                                  authorization=None):
        """Perform a DELETE request to
        /public/v{version}/appointment/deleteappointmentaddon.

        This endpoint can be used to early-cancel a booked appointment add-on.

        Args:
            version (str): version of the api.
            id (int): The request query parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            void: Response from the API. This endpoint does not return a response. If
                a call to this endpoint results in a 204 No Content HTTP status code,
                then the call was successful.

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/appointment/deleteappointmentaddon")
            .http_method(HttpMethodEnum.DELETE)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .query_param(Parameter()
                .key("id")
                .value(id))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .auth(Single("API-Key")),
        ).execute()



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class CreditCardInfo(object):
    """Implementation of the 'CreditCardInfo' model.

    Information about an individual credit card

    Attributes:
        credit_card_number (str): The model property of type str.
        exp_month (str): The model property of type str.
        exp_year (str): The model property of type str.
        billing_name (str): The model property of type str.
        billing_address (str): The model property of type str.
        billing_city (str): The model property of type str.
        billing_state (str): The model property of type str.
        billing_postal_code (str): The model property of type str.
        save_info (bool): The model property of type bool.
        card_id (str): Card Id of a stored instruments card
        cvv (str): CVV of the card

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "credit_card_number": "CreditCardNumber",
        "exp_month": "ExpMonth",
        "exp_year": "ExpYear",
        "billing_name": "BillingName",
        "billing_address": "BillingAddress",
        "billing_city": "BillingCity",
        "billing_state": "BillingState",
        "billing_postal_code": "BillingPostalCode",
        "save_info": "SaveInfo",
        "card_id": "CardId",
        "cvv": "CVV",
    }

    _optionals = [
        "credit_card_number",
        "exp_month",
        "exp_year",
        "billing_name",
        "billing_address",
        "billing_city",
        "billing_state",
        "billing_postal_code",
        "save_info",
        "card_id",
        "cvv",
    ]

    def __init__(
        self,
        credit_card_number=APIHelper.SKIP,
        exp_month=APIHelper.SKIP,
        exp_year=APIHelper.SKIP,
        billing_name=APIHelper.SKIP,
        billing_address=APIHelper.SKIP,
        billing_city=APIHelper.SKIP,
        billing_state=APIHelper.SKIP,
        billing_postal_code=APIHelper.SKIP,
        save_info=APIHelper.SKIP,
        card_id=APIHelper.SKIP,
        cvv=APIHelper.SKIP):
        """Initialize a CreditCardInfo instance."""
        # Initialize members of the class
        if credit_card_number is not APIHelper.SKIP:
            self.credit_card_number = credit_card_number
        if exp_month is not APIHelper.SKIP:
            self.exp_month = exp_month
        if exp_year is not APIHelper.SKIP:
            self.exp_year = exp_year
        if billing_name is not APIHelper.SKIP:
            self.billing_name = billing_name
        if billing_address is not APIHelper.SKIP:
            self.billing_address = billing_address
        if billing_city is not APIHelper.SKIP:
            self.billing_city = billing_city
        if billing_state is not APIHelper.SKIP:
            self.billing_state = billing_state
        if billing_postal_code is not APIHelper.SKIP:
            self.billing_postal_code = billing_postal_code
        if save_info is not APIHelper.SKIP:
            self.save_info = save_info
        if card_id is not APIHelper.SKIP:
            self.card_id = card_id
        if cvv is not APIHelper.SKIP:
            self.cvv = cvv

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        credit_card_number =\
            dictionary.get("CreditCardNumber")\
            if dictionary.get("CreditCardNumber")\
                else APIHelper.SKIP
        exp_month =\
            dictionary.get("ExpMonth")\
            if dictionary.get("ExpMonth")\
                else APIHelper.SKIP
        exp_year =\
            dictionary.get("ExpYear")\
            if dictionary.get("ExpYear")\
                else APIHelper.SKIP
        billing_name =\
            dictionary.get("BillingName")\
            if dictionary.get("BillingName")\
                else APIHelper.SKIP
        billing_address =\
            dictionary.get("BillingAddress")\
            if dictionary.get("BillingAddress")\
                else APIHelper.SKIP
        billing_city =\
            dictionary.get("BillingCity")\
            if dictionary.get("BillingCity")\
                else APIHelper.SKIP
        billing_state =\
            dictionary.get("BillingState")\
            if dictionary.get("BillingState")\
                else APIHelper.SKIP
        billing_postal_code =\
            dictionary.get("BillingPostalCode")\
            if dictionary.get("BillingPostalCode")\
                else APIHelper.SKIP
        save_info =\
            dictionary.get("SaveInfo")\
            if "SaveInfo" in dictionary.keys()\
                else APIHelper.SKIP
        card_id =\
            dictionary.get("CardId")\
            if dictionary.get("CardId")\
                else APIHelper.SKIP
        cvv =\
            dictionary.get("CVV")\
            if dictionary.get("CVV")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(credit_card_number,
                   exp_month,
                   exp_year,
                   billing_name,
                   billing_address,
                   billing_city,
                   billing_state,
                   billing_postal_code,
                   save_info,
                   card_id,
                   cvv)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _credit_card_number=(
            self.credit_card_number
            if hasattr(self, "credit_card_number")
            else None
        )
        _exp_month=(
            self.exp_month
            if hasattr(self, "exp_month")
            else None
        )
        _exp_year=(
            self.exp_year
            if hasattr(self, "exp_year")
            else None
        )
        _billing_name=(
            self.billing_name
            if hasattr(self, "billing_name")
            else None
        )
        _billing_address=(
            self.billing_address
            if hasattr(self, "billing_address")
            else None
        )
        _billing_city=(
            self.billing_city
            if hasattr(self, "billing_city")
            else None
        )
        _billing_state=(
            self.billing_state
            if hasattr(self, "billing_state")
            else None
        )
        _billing_postal_code=(
            self.billing_postal_code
            if hasattr(self, "billing_postal_code")
            else None
        )
        _save_info=(
            self.save_info
            if hasattr(self, "save_info")
            else None
        )
        _card_id=(
            self.card_id
            if hasattr(self, "card_id")
            else None
        )
        _cvv=(
            self.cvv
            if hasattr(self, "cvv")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"credit_card_number={_credit_card_number!r}, "
            f"exp_month={_exp_month!r}, "
            f"exp_year={_exp_year!r}, "
            f"billing_name={_billing_name!r}, "
            f"billing_address={_billing_address!r}, "
            f"billing_city={_billing_city!r}, "
            f"billing_state={_billing_state!r}, "
            f"billing_postal_code={_billing_postal_code!r}, "
            f"save_info={_save_info!r}, "
            f"card_id={_card_id!r}, "
            f"cvv={_cvv!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _credit_card_number=(
            self.credit_card_number
            if hasattr(self, "credit_card_number")
            else None
        )
        _exp_month=(
            self.exp_month
            if hasattr(self, "exp_month")
            else None
        )
        _exp_year=(
            self.exp_year
            if hasattr(self, "exp_year")
            else None
        )
        _billing_name=(
            self.billing_name
            if hasattr(self, "billing_name")
            else None
        )
        _billing_address=(
            self.billing_address
            if hasattr(self, "billing_address")
            else None
        )
        _billing_city=(
            self.billing_city
            if hasattr(self, "billing_city")
            else None
        )
        _billing_state=(
            self.billing_state
            if hasattr(self, "billing_state")
            else None
        )
        _billing_postal_code=(
            self.billing_postal_code
            if hasattr(self, "billing_postal_code")
            else None
        )
        _save_info=(
            self.save_info
            if hasattr(self, "save_info")
            else None
        )
        _card_id=(
            self.card_id
            if hasattr(self, "card_id")
            else None
        )
        _cvv=(
            self.cvv
            if hasattr(self, "cvv")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"credit_card_number={_credit_card_number!s}, "
            f"exp_month={_exp_month!s}, "
            f"exp_year={_exp_year!s}, "
            f"billing_name={_billing_name!s}, "
            f"billing_address={_billing_address!s}, "
            f"billing_city={_billing_city!s}, "
            f"billing_state={_billing_state!s}, "
            f"billing_postal_code={_billing_postal_code!s}, "
            f"save_info={_save_info!s}, "
            f"card_id={_card_id!s}, "
            f"cvv={_cvv!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class FormulaNoteResponse(object):
    """Implementation of the 'FormulaNoteResponse' model.

    An individual Client Formula Note.

    Attributes:
        id (int): The formula note ID.
        client_id (str): The unique Id of the client for the formula note. This is
            the unique ID for the client in the site where the formula note
            originated. This is different than the ClientId specified in the request,
            which is the id for the client assigned by the business.
        appointment_id (int): The appointment ID that the formula note is related to.
        entry_date (datetime): The date formula note was created.
        note (str): The new formula note text.
        site_id (int): The site Id.
        site_name (str): The site name.
        staff_first_name (str): The first name of the staff for the optional
            associated appointment. If no appointment ID is provided, this will be
            null.
        staff_last_name (str): The last name of the staff for the optional associated
            appointment. If no appointment ID is provided, this will be null.
        staff_display_name (str): The display name of the staff for the optional
            associated appointment. If no appointment ID is provided, or no display
            name is specified for the staff member, this will be null.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "id": "Id",
        "client_id": "ClientId",
        "appointment_id": "AppointmentId",
        "entry_date": "EntryDate",
        "note": "Note",
        "site_id": "SiteId",
        "site_name": "SiteName",
        "staff_first_name": "StaffFirstName",
        "staff_last_name": "StaffLastName",
        "staff_display_name": "StaffDisplayName",
    }

    _optionals = [
        "id",
        "client_id",
        "appointment_id",
        "entry_date",
        "note",
        "site_id",
        "site_name",
        "staff_first_name",
        "staff_last_name",
        "staff_display_name",
    ]

    def __init__(
        self,
        id=APIHelper.SKIP,
        client_id=APIHelper.SKIP,
        appointment_id=APIHelper.SKIP,
        entry_date=APIHelper.SKIP,
        note=APIHelper.SKIP,
        site_id=APIHelper.SKIP,
        site_name=APIHelper.SKIP,
        staff_first_name=APIHelper.SKIP,
        staff_last_name=APIHelper.SKIP,
        staff_display_name=APIHelper.SKIP):
        """Initialize a FormulaNoteResponse instance."""
        # Initialize members of the class
        if id is not APIHelper.SKIP:
            self.id = id
        if client_id is not APIHelper.SKIP:
            self.client_id = client_id
        if appointment_id is not APIHelper.SKIP:
            self.appointment_id = appointment_id
        if entry_date is not APIHelper.SKIP:
            self.entry_date =\
                 APIHelper.apply_datetime_converter(
                entry_date, APIHelper.RFC3339DateTime)\
                 if entry_date else None
        if note is not APIHelper.SKIP:
            self.note = note
        if site_id is not APIHelper.SKIP:
            self.site_id = site_id
        if site_name is not APIHelper.SKIP:
            self.site_name = site_name
        if staff_first_name is not APIHelper.SKIP:
            self.staff_first_name = staff_first_name
        if staff_last_name is not APIHelper.SKIP:
            self.staff_last_name = staff_last_name
        if staff_display_name is not APIHelper.SKIP:
            self.staff_display_name = staff_display_name

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        id =\
            dictionary.get("Id")\
            if dictionary.get("Id")\
                else APIHelper.SKIP
        client_id =\
            dictionary.get("ClientId")\
            if dictionary.get("ClientId")\
                else APIHelper.SKIP
        appointment_id =\
            dictionary.get("AppointmentId")\
            if dictionary.get("AppointmentId")\
                else APIHelper.SKIP
        entry_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("EntryDate")).datetime\
            if dictionary.get("EntryDate") else APIHelper.SKIP
        note =\
            dictionary.get("Note")\
            if dictionary.get("Note")\
                else APIHelper.SKIP
        site_id =\
            dictionary.get("SiteId")\
            if dictionary.get("SiteId")\
                else APIHelper.SKIP
        site_name =\
            dictionary.get("SiteName")\
            if dictionary.get("SiteName")\
                else APIHelper.SKIP
        staff_first_name =\
            dictionary.get("StaffFirstName")\
            if dictionary.get("StaffFirstName")\
                else APIHelper.SKIP
        staff_last_name =\
            dictionary.get("StaffLastName")\
            if dictionary.get("StaffLastName")\
                else APIHelper.SKIP
        staff_display_name =\
            dictionary.get("StaffDisplayName")\
            if dictionary.get("StaffDisplayName")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(id,
                   client_id,
                   appointment_id,
                   entry_date,
                   note,
                   site_id,
                   site_name,
                   staff_first_name,
                   staff_last_name,
                   staff_display_name)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _entry_date=(
            self.entry_date
            if hasattr(self, "entry_date")
            else None
        )
        _note=(
            self.note
            if hasattr(self, "note")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _site_name=(
            self.site_name
            if hasattr(self, "site_name")
            else None
        )
        _staff_first_name=(
            self.staff_first_name
            if hasattr(self, "staff_first_name")
            else None
        )
        _staff_last_name=(
            self.staff_last_name
            if hasattr(self, "staff_last_name")
            else None
        )
        _staff_display_name=(
            self.staff_display_name
            if hasattr(self, "staff_display_name")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!r}, "
            f"client_id={_client_id!r}, "
            f"appointment_id={_appointment_id!r}, "
            f"entry_date={_entry_date!r}, "
            f"note={_note!r}, "
            f"site_id={_site_id!r}, "
            f"site_name={_site_name!r}, "
            f"staff_first_name={_staff_first_name!r}, "
            f"staff_last_name={_staff_last_name!r}, "
            f"staff_display_name={_staff_display_name!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _id=(
            self.id
            if hasattr(self, "id")
            else None
        )
        _client_id=(
            self.client_id
            if hasattr(self, "client_id")
            else None
        )
        _appointment_id=(
            self.appointment_id
            if hasattr(self, "appointment_id")
            else None
        )
        _entry_date=(
            self.entry_date
            if hasattr(self, "entry_date")
            else None
        )
        _note=(
            self.note
            if hasattr(self, "note")
            else None
        )
        _site_id=(
            self.site_id
            if hasattr(self, "site_id")
            else None
        )
        _site_name=(
            self.site_name
            if hasattr(self, "site_name")
            else None
        )
        _staff_first_name=(
            self.staff_first_name
            if hasattr(self, "staff_first_name")
            else None
        )
        _staff_last_name=(
            self.staff_last_name
            if hasattr(self, "staff_last_name")
            else None
        )
        _staff_display_name=(
            self.staff_display_name
            if hasattr(self, "staff_display_name")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"id={_id!s}, "
            f"client_id={_client_id!s}, "
            f"appointment_id={_appointment_id!s}, "
            f"entry_date={_entry_date!s}, "
            f"note={_note!s}, "
            f"site_id={_site_id!s}, "
            f"site_name={_site_name!s}, "
            f"staff_first_name={_staff_first_name!s}, "
            f"staff_last_name={_staff_last_name!s}, "
            f"staff_display_name={_staff_display_name!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: D410, E501, E101, D206
from apimatic_core.authentication.multiple.single_auth import (
    Single,
)
from apimatic_core.request_builder import RequestBuilder
from apimatic_core.response_handler import ResponseHandler
from apimatic_core.types.parameter import Parameter

from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.configuration import (
    Server,
)
from mindbodypublicapi.controllers.base_controller import (
    BaseController,
)
from mindbodypublicapi.http.http_method_enum import (
    HttpMethodEnum,
)
from mindbodypublicapi.models.add_staff_response import (
    AddStaffResponse,
)
from mindbodypublicapi.models.assign_staff_session_type_response import (
    AssignStaffSessionTypeResponse,
)
from mindbodypublicapi.models.get_sales_reps_response import (
    GetSalesRepsResponse,
)
from mindbodypublicapi.models.get_staff_image_url_response import (
    GetStaffImageURLResponse,
)
from mindbodypublicapi.models.get_staff_permissions_response import (
    GetStaffPermissionsResponse,
)
from mindbodypublicapi.models.get_staff_response import (
    GetStaffResponse,
)
from mindbodypublicapi.models.get_staff_session_types_response import (
    GetStaffSessionTypesResponse,
)
from mindbodypublicapi.models.update_staff_permissions_response import (
    UpdateStaffPermissionsResponse,
)
from mindbodypublicapi.models.update_staff_response import (
    UpdateStaffResponse,
)


class StaffController(BaseController):
    """A Controller to access Endpoints in the mindbodypublicapi API."""

    def __init__(self, config):
        """Initialize StaffController object."""
        super(StaffController, self).__init__(config)

    def get_staff_image_url(self,
                            version,
                            site_id,
                            authorization=None,
                            request_staff_id=None):
        """Perform a GET request to /public/v{version}/staff/imageurl.

        Retrieves the available image URLs for a specified staff member, including
        desktop and mobile versions.
        <br />
        The resolution of these images is determined by the Mindbody product at the
        time the image is uploaded. Staff images are automatically resized within
        Core (typically around 200×151 pixels), and this endpoint surfaces only the
        stored versions. The API does not resize or limit the images itself .
        <br />
        For more information about how image sizes are managed in Mindbody product,
        refer to the related support article: [link
        here](https://support.mindbodyonline.com/s/article/203253783-Staff-profiles-Cr
        eating-logins-updating-info-and-enabling-settings?language=en_US).

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_staff_id (int, optional): The ID of the staff member whose image
                URL details you want to retrieve.

        Returns:
            GetStaffImageURLResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/imageurl")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.staffId")
                .value(request_staff_id))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetStaffImageURLResponse.from_dictionary),
        ).execute()

    def get_sales_reps(self,
                       version,
                       site_id,
                       authorization=None,
                       request_active_only=None,
                       request_limit=None,
                       request_offset=None,
                       request_sales_rep_numbers=None):
        """Perform a GET request to /public/v{version}/staff/salesreps.

        This endpoint returns the basic details of the staffs that are marked as
        sales reps.

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_active_only (bool, optional): When `true`, will return only
                active reps data.  Default : **false**
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_sales_rep_numbers (List[int], optional): This is the list of the
                sales rep numbers for which the salesrep data will be fetched.

        Returns:
            GetSalesRepsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/salesreps")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.activeOnly")
                .value(request_active_only))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.salesRepNumbers")
                .value(request_sales_rep_numbers))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetSalesRepsResponse.from_dictionary),
        ).execute()

    def get_staff_session_types(self,
                                version,
                                request_staff_id,
                                site_id,
                                authorization=None,
                                request_limit=None,
                                request_offset=None,
                                request_online_only=None,
                                request_program_ids=None):
        """Perform a GET request to /public/v{version}/staff/sessiontypes.

        Gets a list of active session types for a specific staff member. A staff user
        token must be included with staff assigned the ManageStaffPayRates permission.

        Args:
            version (str): version of the api.
            request_staff_id (int): The ID of the staff member whose session types
                you want to return.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_offset (int, optional): Page offset, defaults to 0.
            request_online_only (bool, optional): When `true`, indicates that only
                the session types that can be booked online should be returned.
                Default: **false**
            request_program_ids (List[int], optional): Filters results to session
                types that belong to one of the given program IDs. If omitted, all
                program IDs return.

        Returns:
            GetStaffSessionTypesResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/sessiontypes")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .query_param(Parameter()
                .key("request.staffId")
                .value(request_staff_id))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.onlineOnly")
                .value(request_online_only))
            .query_param(Parameter()
                .key("request.programIds")
                .value(request_program_ids))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetStaffSessionTypesResponse.from_dictionary),
        ).execute()

    def get_staff(self,
                  version,
                  site_id,
                  authorization=None,
                  request_filters=None,
                  request_limit=None,
                  request_location_id=None,
                  request_offset=None,
                  request_session_type_id=None,
                  request_staff_ids=None,
                  request_start_date_time=None):
        """Perform a GET request to /public/v{version}/staff/staff.

        When a user token is not passed with the request or the passed user token has
        insufficient viewing permissions, only the following staff data is returned
        in the response:

        * FirstName
        * LastName
        * Id
        * Bio
        * DisplayName
        * ImageUrl
        * EmpID

        Args:
            version (str): version of the api.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.
            request_filters (List[str], optional): Filters to apply to the search.
                Possible values are:  * StaffViewable  * AppointmentInstructor  *
                ClassInstructor  * Male  * Female
            request_limit (int, optional): Number of results to include, defaults to
                100
            request_location_id (int, optional): Return only staff members that are
                available at the specified location. You must supply a valid
                `SessionTypeID` and `StartDateTime` to use this parameter.
            request_offset (int, optional): Page offset, defaults to 0.
            request_session_type_id (int, optional): Return only staff members that
                are available for the specified session type. You must supply a valid
                `StartDateTime` and `LocationID` to use this parameter.
            request_staff_ids (List[int], optional): A list of the requested staff
                IDs.
            request_start_date_time (datetime, optional): Return only staff members
                that are available at the specified date and time. You must supply a
                valid `SessionTypeID` and `LocationID` to use this parameter.

        Returns:
            GetStaffResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/staff")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .query_param(Parameter()
                .key("request.filters")
                .value(request_filters))
            .query_param(Parameter()
                .key("request.limit")
                .value(request_limit))
            .query_param(Parameter()
                .key("request.locationId")
                .value(request_location_id))
            .query_param(Parameter()
                .key("request.offset")
                .value(request_offset))
            .query_param(Parameter()
                .key("request.sessionTypeId")
                .value(request_session_type_id))
            .query_param(Parameter()
                .key("request.staffIds")
                .value(request_staff_ids))
            .query_param(Parameter()
                .key("request.startDateTime")
                .value(APIHelper.when_defined(APIHelper.RFC3339DateTime,
                    request_start_date_time)))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetStaffResponse.from_dictionary),
        ).execute()

    def get_staff_permissions(self,
                              version,
                              request_staff_id,
                              site_id,
                              authorization=None):
        """Perform a GET request to /public/v{version}/staff/staffpermissions.

        Get configured staff permissions for a staff member.

        Args:
            version (str): version of the api.
            request_staff_id (int): The ID of the staff member whose permissions you
                want to return.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            GetStaffPermissionsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/staffpermissions")
            .http_method(HttpMethodEnum.GET)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .query_param(Parameter()
                .key("request.staffId")
                .value(request_staff_id))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(GetStaffPermissionsResponse.from_dictionary),
        ).execute()

    def add_staff(self,
                  version,
                  request,
                  site_id,
                  authorization=None):
        """Perform a POST request to /public/v{version}/staff/addstaff.

        Creates a new staff member record at the specified business. The `FirstName`
        and `LastName` parameters are always required for this request.

        Args:
            version (str): version of the api.
            request (AddStaffRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            AddStaffResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/addstaff")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AddStaffResponse.from_dictionary),
        ).execute()

    def assign_staff_session_type(self,
                                  version,
                                  request,
                                  site_id,
                                  authorization=None):
        """Perform a POST request to
        /public/v{version}/staff/assignsessiontype.

        Assigns a staff member to an appointment session type with staff specific
        properties such as time length and pay rate. A staff user token must be
        included with staff assigned the ManageStaffPayRates permission.

        Args:
            version (str): version of the api.
            request (AssignStaffSessionTypeRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            AssignStaffSessionTypeResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/assignsessiontype")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(AssignStaffSessionTypeResponse.from_dictionary),
        ).execute()

    def add_staff_availability(self,
                               version,
                               request,
                               site_id,
                               authorization=None):
        """Perform a POST request to
        /public/v{version}/staff/staffavailability.

        Enables to add staff availability or unavailability for a given staff member.

        Args:
            version (str): version of the api.
            request (AddStaffAvailabilityRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            void: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/staffavailability")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).execute()

    def update_staff(self,
                     version,
                     request,
                     site_id,
                     authorization=None):
        """Perform a POST request to /public/v{version}/staff/updatestaff.

        Updates an existing staff member record at the specified business. The ID is
        a required parameters for this request.

        Args:
            version (str): version of the api.
            request (UpdateStaffRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            UpdateStaffResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/updatestaff")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(UpdateStaffResponse.from_dictionary),
        ).execute()

    def update_staff_permissions(self,
                                 version,
                                 request,
                                 site_id,
                                 authorization=None):
        """Perform a POST request to
        /public/v{version}/staff/updatestaffpermissions.

        Assigns a permission group to a staff member. A staff user token must be
        included with staff assigned the ManageStaffPayRates permission.

        Args:
            version (str): version of the api.
            request (UpdateStaffPermissionsRequest): The request body parameter.
            site_id (str): ID of the site from which to pull data.
            authorization (str, optional): A staff user authorization token.

        Returns:
            UpdateStaffPermissionsResponse: Response from the API. OK

        Raises:
            APIException: When an error occurs while fetching the data from the
                remote API. This exception includes the HTTP Response code, an error
                message, and the HTTP body that was received in the request.

        """
        return super().new_api_call_builder.request(
            RequestBuilder().server(Server.DEFAULT)
            .path("/public/v{version}/staff/updatestaffpermissions")
            .http_method(HttpMethodEnum.POST)
            .template_param(Parameter()
                .key("version")
                .value(version)
                .should_encode(True))
            .body_param(Parameter()
                .value(request))
            .header_param(Parameter()
                .key("siteId")
                .value(site_id))
            .header_param(Parameter()
                .key("Content-Type")
                .value("application/json"))
            .header_param(Parameter()
                .key("authorization")
                .value(authorization))
            .header_param(Parameter()
                .key("accept")
                .value("application/json"))
            .body_serializer(APIHelper.json_serialize)
            .auth(Single("API-Key")),
        ).response(
            ResponseHandler()
            .deserializer(APIHelper.json_deserialize)
            .deserialize_into(UpdateStaffPermissionsResponse.from_dictionary),
        ).execute()



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetClientIndexesRequest(object):
    """Implementation of the 'GetClientIndexesRequest' model.

    Attributes:
        required_only (bool): When `true`, filters the results to only indexes that
            are required on creation.<br />  When `false` or omitted, returns all of
            the client indexes.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "required_only": "RequiredOnly",
    }

    _optionals = [
        "required_only",
    ]

    def __init__(
        self,
        required_only=APIHelper.SKIP):
        """Initialize a GetClientIndexesRequest instance."""
        # Initialize members of the class
        if required_only is not APIHelper.SKIP:
            self.required_only = required_only

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        required_only =\
            dictionary.get("RequiredOnly")\
            if "RequiredOnly" in dictionary.keys()\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(required_only)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _required_only=(
            self.required_only
            if hasattr(self, "required_only")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"required_only={_required_only!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _required_only=(
            self.required_only
            if hasattr(self, "required_only")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"required_only={_required_only!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class IssueRequest(object):
    """Implementation of the 'IssueRequest' model.

    POST UserToken/Issue request

    Attributes:
        username (str): The staff member’s username.
        password (str): The staff member’s password.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "username": "Username",
        "password": "Password",
    }

    _optionals = [
        "username",
        "password",
    ]

    def __init__(
        self,
        username=APIHelper.SKIP,
        password=APIHelper.SKIP):
        """Initialize a IssueRequest instance."""
        # Initialize members of the class
        if username is not APIHelper.SKIP:
            self.username = username
        if password is not APIHelper.SKIP:
            self.password = password

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        username =\
            dictionary.get("Username")\
            if dictionary.get("Username")\
                else APIHelper.SKIP
        password =\
            dictionary.get("Password")\
            if dictionary.get("Password")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(username,
                   password)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _username=(
            self.username
            if hasattr(self, "username")
            else None
        )
        _password=(
            self.password
            if hasattr(self, "password")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"username={_username!r}, "
            f"password={_password!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _username=(
            self.username
            if hasattr(self, "username")
            else None
        )
        _password=(
            self.password
            if hasattr(self, "password")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"username={_username!s}, "
            f"password={_password!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper


class GetProgramsRequest(object):
    """Implementation of the 'GetProgramsRequest' model.

    Attributes:
        schedule_type (ScheduleType3Enum): A schedule type used to filter the
            returned results. Possible values are:  * All  * Class  * Enrollment  *
            Appointment  * Resource  * Media  * Arrival
        online_only (bool): If `true`, filters results to show only those programs
            that are shown online.<br />  If `false`, all programs are returned.<br
            />  Default: **false**
        program_ids (List[int]): Program Ids to filter for
        limit (int): Number of results to include, defaults to 100
        offset (int): Page offset, defaults to 0.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "schedule_type": "ScheduleType",
        "online_only": "OnlineOnly",
        "program_ids": "ProgramIds",
        "limit": "Limit",
        "offset": "Offset",
    }

    _optionals = [
        "schedule_type",
        "online_only",
        "program_ids",
        "limit",
        "offset",
    ]

    def __init__(
        self,
        schedule_type=APIHelper.SKIP,
        online_only=APIHelper.SKIP,
        program_ids=APIHelper.SKIP,
        limit=APIHelper.SKIP,
        offset=APIHelper.SKIP):
        """Initialize a GetProgramsRequest instance."""
        # Initialize members of the class
        if schedule_type is not APIHelper.SKIP:
            self.schedule_type = schedule_type
        if online_only is not APIHelper.SKIP:
            self.online_only = online_only
        if program_ids is not APIHelper.SKIP:
            self.program_ids = program_ids
        if limit is not APIHelper.SKIP:
            self.limit = limit
        if offset is not APIHelper.SKIP:
            self.offset = offset

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        schedule_type =\
            dictionary.get("ScheduleType")\
            if dictionary.get("ScheduleType")\
                else APIHelper.SKIP
        online_only =\
            dictionary.get("OnlineOnly")\
            if "OnlineOnly" in dictionary.keys()\
                else APIHelper.SKIP
        program_ids =\
            dictionary.get("ProgramIds")\
            if dictionary.get("ProgramIds")\
                else APIHelper.SKIP
        limit =\
            dictionary.get("Limit")\
            if dictionary.get("Limit")\
                else APIHelper.SKIP
        offset =\
            dictionary.get("Offset")\
            if dictionary.get("Offset")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(schedule_type,
                   online_only,
                   program_ids,
                   limit,
                   offset)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _schedule_type=(
            self.schedule_type
            if hasattr(self, "schedule_type")
            else None
        )
        _online_only=(
            self.online_only
            if hasattr(self, "online_only")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"schedule_type={_schedule_type!r}, "
            f"online_only={_online_only!r}, "
            f"program_ids={_program_ids!r}, "
            f"limit={_limit!r}, "
            f"offset={_offset!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _schedule_type=(
            self.schedule_type
            if hasattr(self, "schedule_type")
            else None
        )
        _online_only=(
            self.online_only
            if hasattr(self, "online_only")
            else None
        )
        _program_ids=(
            self.program_ids
            if hasattr(self, "program_ids")
            else None
        )
        _limit=(
            self.limit
            if hasattr(self, "limit")
            else None
        )
        _offset=(
            self.offset
            if hasattr(self, "offset")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"schedule_type={_schedule_type!s}, "
            f"online_only={_online_only!s}, "
            f"program_ids={_program_ids!s}, "
            f"limit={_limit!s}, "
            f"offset={_offset!s}, "
            f")"
        )



"""mindbodypublicapi.

This file was automatically generated by APIMATIC v3.0 ( https://www.apimatic.io ).
"""

# ruff: noqa: E501
from mindbodypublicapi.api_helper import APIHelper
from mindbodypublicapi.models.checkout_payment_info import (
    CheckoutPaymentInfo,
)


class PurchaseGiftCardRequest(object):
    """Implementation of the 'PurchaseGiftCardRequest' model.

    Attributes:
        test (bool): When `true`, allows you to test the request without affecting
            the database.<br />  When `false`, the request is carried out and the
            database is affected.
        location_id (int): The ID of the location where the gift card is being sold.
        layout_id (int): The ID of the layout used for the gift card’s image.
        purchaser_client_id (str): The RSSID of the client who is purchasing the gift
            card.
        gift_card_id (int): The product ID of the gift card being purchased.
        send_email_receipt (bool): When `true`, indicates that a purchase receipt
            email should be sent to the purchasing client, if all settings are
            correctly configured.<br />  When `false`, no email is sent to the
            purchaser.
        recipient_email (str): The email address to send the gift card image to. This
            parameter is required if the `LayoutId` is not 0.<br />  Maximum length:
            **100**
        recipient_name (str): The name of the person who is to receive the gift card.
            This parameter is required if the `LayoutId` is not 0.<br />  Maximum
            length: **20**
        title (str): The text to use as the title of the gift card, for example:
            Happy Birthday, Maria! This parameter is required if the `LayoutId` is
            not 0.<br />  Maximum length: **20**
        gift_message (str): A personal message to include in the gift card.<br />
            Maximum length: **300**
        delivery_date (datetime): The date that the gift card’s image is to be
            delivered to the recipient. This parameter cannot be set to a date in the
            past. This parameter is required if the `LayoutId` is not 0.  Default:
            **today**  Minimum: **today**
        payment_info (CheckoutPaymentInfo): The model property of type
            CheckoutPaymentInfo.
        sales_rep_id (int): The ID of the staff member who is to be marked as the
            sales rep for this gift card purchase.
        consumer_present (bool): When `true`, indicates that the consumer is
            available to address any SCA challenge issued by the bank.  EU Only.<br
            />   Default: **false**
        payment_authentication_callback_url (str): This is the Url the consumer will
            be redirected back to after completion of the Banks SCA challenge.
        barcode_id (str): Sets the barcode ID of the giftcard. When not provided, a
            barcode ID is automatically generated.<br />  If a giftcard with the
            given barcode ID already exists and the site supports reloadable
            giftcards, the existing giftcard is reloaded<br />  Maximum length:
            **100**
        sender_name (str): Overrides the name that would otherwise be populated by
            specifying PurchaserClientId.<br />  Maximum length: **20**

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "location_id": "LocationId",
        "purchaser_client_id": "PurchaserClientId",
        "gift_card_id": "GiftCardId",
        "test": "Test",
        "layout_id": "LayoutId",
        "send_email_receipt": "SendEmailReceipt",
        "recipient_email": "RecipientEmail",
        "recipient_name": "RecipientName",
        "title": "Title",
        "gift_message": "GiftMessage",
        "delivery_date": "DeliveryDate",
        "payment_info": "PaymentInfo",
        "sales_rep_id": "SalesRepId",
        "consumer_present": "ConsumerPresent",
        "payment_authentication_callback_url": "PaymentAuthenticationCallbackUrl",
        "barcode_id": "BarcodeId",
        "sender_name": "SenderName",
    }

    _optionals = [
        "test",
        "layout_id",
        "send_email_receipt",
        "recipient_email",
        "recipient_name",
        "title",
        "gift_message",
        "delivery_date",
        "payment_info",
        "sales_rep_id",
        "consumer_present",
        "payment_authentication_callback_url",
        "barcode_id",
        "sender_name",
    ]

    def __init__(
        self,
        location_id=None,
        purchaser_client_id=None,
        gift_card_id=None,
        test=APIHelper.SKIP,
        layout_id=APIHelper.SKIP,
        send_email_receipt=APIHelper.SKIP,
        recipient_email=APIHelper.SKIP,
        recipient_name=APIHelper.SKIP,
        title=APIHelper.SKIP,
        gift_message=APIHelper.SKIP,
        delivery_date=APIHelper.SKIP,
        payment_info=APIHelper.SKIP,
        sales_rep_id=APIHelper.SKIP,
        consumer_present=APIHelper.SKIP,
        payment_authentication_callback_url=APIHelper.SKIP,
        barcode_id=APIHelper.SKIP,
        sender_name=APIHelper.SKIP):
        """Initialize a PurchaseGiftCardRequest instance."""
        # Initialize members of the class
        if test is not APIHelper.SKIP:
            self.test = test
        self.location_id = location_id
        if layout_id is not APIHelper.SKIP:
            self.layout_id = layout_id
        self.purchaser_client_id = purchaser_client_id
        self.gift_card_id = gift_card_id
        if send_email_receipt is not APIHelper.SKIP:
            self.send_email_receipt = send_email_receipt
        if recipient_email is not APIHelper.SKIP:
            self.recipient_email = recipient_email
        if recipient_name is not APIHelper.SKIP:
            self.recipient_name = recipient_name
        if title is not APIHelper.SKIP:
            self.title = title
        if gift_message is not APIHelper.SKIP:
            self.gift_message = gift_message
        if delivery_date is not APIHelper.SKIP:
            self.delivery_date =\
                 APIHelper.apply_datetime_converter(
                delivery_date, APIHelper.RFC3339DateTime)\
                 if delivery_date else None
        if payment_info is not APIHelper.SKIP:
            self.payment_info = payment_info
        if sales_rep_id is not APIHelper.SKIP:
            self.sales_rep_id = sales_rep_id
        if consumer_present is not APIHelper.SKIP:
            self.consumer_present = consumer_present
        if payment_authentication_callback_url is not APIHelper.SKIP:
            self.payment_authentication_callback_url =\
                 payment_authentication_callback_url
        if barcode_id is not APIHelper.SKIP:
            self.barcode_id = barcode_id
        if sender_name is not APIHelper.SKIP:
            self.sender_name = sender_name

    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Create an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object
            as obtained from the deserialization of the server's response. The
            keys MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if not isinstance(dictionary, dict) or dictionary is None:
            return None

        # Extract variables from the dictionary
        location_id =\
            dictionary.get("LocationId")\
            if dictionary.get("LocationId")\
                else None
        purchaser_client_id =\
            dictionary.get("PurchaserClientId")\
            if dictionary.get("PurchaserClientId")\
                else None
        gift_card_id =\
            dictionary.get("GiftCardId")\
            if dictionary.get("GiftCardId")\
                else None
        test =\
            dictionary.get("Test")\
            if "Test" in dictionary.keys()\
                else APIHelper.SKIP
        layout_id =\
            dictionary.get("LayoutId")\
            if dictionary.get("LayoutId")\
                else APIHelper.SKIP
        send_email_receipt =\
            dictionary.get("SendEmailReceipt")\
            if "SendEmailReceipt" in dictionary.keys()\
                else APIHelper.SKIP
        recipient_email =\
            dictionary.get("RecipientEmail")\
            if dictionary.get("RecipientEmail")\
                else APIHelper.SKIP
        recipient_name =\
            dictionary.get("RecipientName")\
            if dictionary.get("RecipientName")\
                else APIHelper.SKIP
        title =\
            dictionary.get("Title")\
            if dictionary.get("Title")\
                else APIHelper.SKIP
        gift_message =\
            dictionary.get("GiftMessage")\
            if dictionary.get("GiftMessage")\
                else APIHelper.SKIP
        delivery_date = APIHelper.RFC3339DateTime.from_value(
            dictionary.get("DeliveryDate")).datetime\
            if dictionary.get("DeliveryDate") else APIHelper.SKIP
        payment_info =\
            CheckoutPaymentInfo.from_dictionary(
                dictionary.get("PaymentInfo"))\
                if "PaymentInfo" in dictionary.keys()\
                else APIHelper.SKIP
        sales_rep_id =\
            dictionary.get("SalesRepId")\
            if dictionary.get("SalesRepId")\
                else APIHelper.SKIP
        consumer_present =\
            dictionary.get("ConsumerPresent")\
            if "ConsumerPresent" in dictionary.keys()\
                else APIHelper.SKIP
        payment_authentication_callback_url =\
            dictionary.get("PaymentAuthenticationCallbackUrl")\
            if dictionary.get("PaymentAuthenticationCallbackUrl")\
                else APIHelper.SKIP
        barcode_id =\
            dictionary.get("BarcodeId")\
            if dictionary.get("BarcodeId")\
                else APIHelper.SKIP
        sender_name =\
            dictionary.get("SenderName")\
            if dictionary.get("SenderName")\
                else APIHelper.SKIP

        # Return an object of this model
        return cls(location_id,
                   purchaser_client_id,
                   gift_card_id,
                   test,
                   layout_id,
                   send_email_receipt,
                   recipient_email,
                   recipient_name,
                   title,
                   gift_message,
                   delivery_date,
                   payment_info,
                   sales_rep_id,
                   consumer_present,
                   payment_authentication_callback_url,
                   barcode_id,
                   sender_name)

    def __repr__(self):
        """Return a unambiguous string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=self.location_id
        _layout_id=(
            self.layout_id
            if hasattr(self, "layout_id")
            else None
        )
        _purchaser_client_id=self.purchaser_client_id
        _gift_card_id=self.gift_card_id
        _send_email_receipt=(
            self.send_email_receipt
            if hasattr(self, "send_email_receipt")
            else None
        )
        _recipient_email=(
            self.recipient_email
            if hasattr(self, "recipient_email")
            else None
        )
        _recipient_name=(
            self.recipient_name
            if hasattr(self, "recipient_name")
            else None
        )
        _title=(
            self.title
            if hasattr(self, "title")
            else None
        )
        _gift_message=(
            self.gift_message
            if hasattr(self, "gift_message")
            else None
        )
        _delivery_date=(
            self.delivery_date
            if hasattr(self, "delivery_date")
            else None
        )
        _payment_info=(
            self.payment_info
            if hasattr(self, "payment_info")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _consumer_present=(
            self.consumer_present
            if hasattr(self, "consumer_present")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _sender_name=(
            self.sender_name
            if hasattr(self, "sender_name")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"test={_test!r}, "
            f"location_id={_location_id!r}, "
            f"layout_id={_layout_id!r}, "
            f"purchaser_client_id={_purchaser_client_id!r}, "
            f"gift_card_id={_gift_card_id!r}, "
            f"send_email_receipt={_send_email_receipt!r}, "
            f"recipient_email={_recipient_email!r}, "
            f"recipient_name={_recipient_name!r}, "
            f"title={_title!r}, "
            f"gift_message={_gift_message!r}, "
            f"delivery_date={_delivery_date!r}, "
            f"payment_info={_payment_info!r}, "
            f"sales_rep_id={_sales_rep_id!r}, "
            f"consumer_present={_consumer_present!r}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!r}, "
            f"barcode_id={_barcode_id!r}, "
            f"sender_name={_sender_name!r}, "
            f")"
        )

    def __str__(self):
        """Return a human-readable string representation."""
        _test=(
            self.test
            if hasattr(self, "test")
            else None
        )
        _location_id=self.location_id
        _layout_id=(
            self.layout_id
            if hasattr(self, "layout_id")
            else None
        )
        _purchaser_client_id=self.purchaser_client_id
        _gift_card_id=self.gift_card_id
        _send_email_receipt=(
            self.send_email_receipt
            if hasattr(self, "send_email_receipt")
            else None
        )
        _recipient_email=(
            self.recipient_email
            if hasattr(self, "recipient_email")
            else None
        )
        _recipient_name=(
            self.recipient_name
            if hasattr(self, "recipient_name")
            else None
        )
        _title=(
            self.title
            if hasattr(self, "title")
            else None
        )
        _gift_message=(
            self.gift_message
            if hasattr(self, "gift_message")
            else None
        )
        _delivery_date=(
            self.delivery_date
            if hasattr(self, "delivery_date")
            else None
        )
        _payment_info=(
            self.payment_info
            if hasattr(self, "payment_info")
            else None
        )
        _sales_rep_id=(
            self.sales_rep_id
            if hasattr(self, "sales_rep_id")
            else None
        )
        _consumer_present=(
            self.consumer_present
            if hasattr(self, "consumer_present")
            else None
        )
        _payment_authentication_callback_url=(
            self.payment_authentication_callback_url
            if hasattr(self, "payment_authentication_callback_url")
            else None
        )
        _barcode_id=(
            self.barcode_id
            if hasattr(self, "barcode_id")
            else None
        )
        _sender_name=(
            self.sender_name
            if hasattr(self, "sender_name")
            else None
        )
        return (
            f"{self.__class__.__name__}("
            f"test={_test!s}, "
            f"location_id={_location_id!s}, "
            f"layout_id={_layout_id!s}, "
            f"purchaser_client_id={_purchaser_client_id!s}, "
            f"gift_card_id={_gift_card_id!s}, "
            f"send_email_receipt={_send_email_receipt!s}, "
            f"recipient_email={_recipient_email!s}, "
            f"recipient_name={_recipient_name!s}, "
            f"title={_title!s}, "
            f"gift_message={_gift_message!s}, "
            f"delivery_date={_delivery_date!s}, "
            f"payment_info={_payment_info!s}, "
            f"sales_rep_id={_sales_rep_id!s}, "
            f"consumer_present={_consumer_present!s}, "
            f"payment_authentication_callback_url={_payment_authentication_callback_url!s}, "
            f"barcode_id={_barcode_id!s}, "
            f"sender_name={_sender_name!s}, "
            f")"
        )
